import { 
  select, 
  json, 
  geoPath, 
  geoMercator, 
  zoom, 
  event, 
  geoCentroid 
} from 'd3';

import { feature } from 'topojson';
import 'bootstrap';
import 'jquery'

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');
const projection = geoMercator()
  .scale(4000)
  .center([-7,53.3])
  .translate([width / 2, height / 2]);
const pathGenerator = geoPath().projection(projection);
const g = svg.append('g');
const div = select("#chart").append("div")	
    .attr("class", "#chart-div")				
    .style("opacity", 1);
const modalSvg = select("#chart").append('svg')
  .attr('width', 220)
  .attr('height', 300);

// const modalSvgG = modalSvg.append('svg');
// const rect = modalSvg.append('rect')
//   .attr('width', 150)
//   .attr('height', 300)
//   .attr('x', 40)
//   .attr('y', 40)
//   .attr('fill', 'red');

const modalSvgG = modalSvg.append('g')
  .attr('transform','translate(0,0)');
const gText = modalSvgG.append('g')
  .attr('transform','translate(105,10)');
const topsoil = modalSvgG.append('rect')
  .attr('height', 50)
  .attr('width', 100)
  .attr('fill', 'brown')
  .on("mouseover", function() {		
      div.transition()		
          .duration(200)		
          .style("opacity", .9);		
      div.html("Depth: 0 - 0.5m")	
          .style("left", (event.pageX) + "px")		
          .style("top", (event.pageY - 28) + "px");	
      })	
  .on("mouseout", function() {		
        div.transition()		
            .duration(500)		
            .style("opacity", 0);	
    });
const topsoilT = gText.append('text')
  .text('Topsoil')
  .attr('y', 30)
  .attr("font-family", "sans-serif")
  .attr("font-size", "20px")
const peat = modalSvgG.append('rect')
  .attr('y', 50)
  .attr('height', 30)
  .attr('width', 100)
  .attr('fill', '#d95f0e')
  .on("mouseover", function() {		
      div.transition()		
          .duration(200)		
          .style("opacity", .9);		
      div.html("Depth: 0.5 - 1.5m")	
          .style("left", (event.pageX) + "px")		
          .style("top", (event.pageY - 28) + "px");	
      })	
  .on("mouseout", function() {		
        div.transition()		
            .duration(500)		
            .style("opacity", 0);	
    });
 
const peatT = gText.append('text')
  .text('Peat')
  .attr('y', 70)
  .attr("font-family", "sans-serif")
  .attr("font-size", "20px");
const till = modalSvgG.append('rect')
  .attr('y', 80)
  .attr('height', 60)
  .attr('width', 100)
  .attr('fill', 'grey')  
  .on("mouseover", function() {		
      div.transition()		
          .duration(200)		
          .style("opacity", .9);		
      div.html("Depth: 1m - 2.5m")	
          .style("left", (event.pageX) + "px")		
          .style("top", (event.pageY - 28) + "px");	
      })	
  .on("mouseout", function() {		
        div.transition()		
            .duration(500)		
            .style("opacity", 0);	
    });
const tillT = gText.append('text')
  .text('Till')
  .attr('y', 120)
  .attr("font-family", "sans-serif")
  .attr("font-size", "20px")
const bedrock = modalSvgG.append('rect')
  .attr('y', 140)
  .attr('height', 1000)
  .attr('width', 100)
  .attr('fill', '#de2d26')
  .on("mouseover", function() {		
      div.transition()		
          .duration(200)		
          .style("opacity", .9);		
      div.html("Depth: 2.5m to Australia")	
          .style("left", (event.pageX) + "px")		
          .style("top", (event.pageY - 28) + "px");	
      })	
  .on("mouseout", function() {		
        div.transition()		
            .duration(500)		
            .style("opacity", 0);	
    });

const bedrockT = gText.append('text')
  .text('Sandstone')
  .attr('y', 190)
  .attr("font-family", "sans-serif")
  .attr("font-size", "20px")
const water = modalSvgG.append("line")
  .attr("x1", 0)
  .attr("y1", 225)
  .attr("x2", 50)
  .attr("y2", 235)
  .attr("stroke-width", 6)
  .attr("stroke", "blue")
  .on("mouseover", function() {		
      div.transition()		
          .duration(200)		
          .style("opacity", .9);		
      div.html("Water at: 3.5m")	
          .style("left", (event.pageX) + "px")		
          .style("top", (event.pageY - 28) + "px");	
      })	
  .on("mouseout", function() {		
        div.transition()		
            .duration(500)		
            .style("opacity", 0);	
    });
const water1 = modalSvgG.append("line")
  .attr("x1", 50)
  .attr("y1", 235)
  .attr("x2", 100)
  .attr("y2", 225)
  .attr("stroke-width", 6)
  .attr("stroke", "blue")
  .on("mouseover", function() {		
      div.transition()		
          .duration(200)		
          .style("opacity", .9);		
      div.html("Water at: 3.5m")	
          .style("left", (event.pageX) + "px")		
          .style("top", (event.pageY - 28) + "px");	
      })	
  .on("mouseout", function() {		
        div.transition()		
            .duration(500)		
            .style("opacity", 0);	
    });
const waterT = gText.append('text')
  .text('Water level')
  .attr('y', 230)
  .attr("font-family", "sans-serif")
  .attr("font-size", "20px")

svg.call(zoom().on('zoom', () =>{
   g.attr('transform', event.transform);
}));

json('https://raw.githubusercontent.com/deldersveld/topojson/master/countries/ireland/ireland-counties.json')
  .then(data => {
    const ireland = feature(data, data.objects.IRL_adm1)
    const paths = g.selectAll('path')
      .data(ireland.features);
    paths.enter().append('path')
      .attr('class', 'counties')
      .attr('d', pathGenerator)
    .append('title')
      .text(d => d.properties.NAME_1);
    const circle = g.selectAll('circle')
      .data(ireland.features);
    circle.enter().append('circle')
      .attr('class', 'counties-circle')
      .attr('cx', d => projection(geoCentroid(d))[0])
      .attr('cy', d => projection(geoCentroid(d))[1])
      .attr('r', 10)
    // .on('click', d => $(".counties-circle").click(()=>
    //   $("#myModal").show()  
    // ));
  $(".counties-circle").click(()=>
      $("#myModal").show())
    $("#closeModal").click(()=>
      $("#myModal").hide())

});